@@ -1,20 +1,19 @@
-import json
-import os
-import logging.config
-from packaging.version import parse as parse_version
 import fair_research_login
 import globus_automate_client
 import globus_sdk
+import json
+import logging.config
+import os
 import requests
 
-from cfde_submit import CONFIG, exc, globus_http, validation
 from .version import __version__ as VERSION
+from cfde_submit import CONFIG, exc, globus_http, validation, bdbag_utils
+from packaging.version import parse as parse_version
 
-logging.config.dictConfig(CONFIG["LOGGING"])
 logger = logging.getLogger(__name__)
 
 
-class CfdeClient():
+class CfdeClient:
     """The CfdeClient enables easily using the CFDE tools to ingest data."""
     client_id = "417301b1-5101-456a-8a27-423e71a2ae26"
     config_filename = os.path.expanduser("~/.cfde-submit.cfg")
@@ -41,9 +40,16 @@ class CfdeClient():
         self.local_config = fair_research_login.ConfigParserTokenStorage(
             filename=self.config_filename
         )
+        cli_message = ('Starting login with Globus Auth, '
+                       'press ^C twice to cancel or once to manually authenticate')
+        code_handlers = [
+            fair_research_login.LocalServerCodeHandler(cli_message=cli_message),
+            fair_research_login.InputCodeHandler(),
+        ]
         self.__native_client = fair_research_login.NativeClient(client_id=self.client_id,
                                                                 app_name=self.app_name,
-                                                                token_storage=self.local_config)
+                                                                token_storage=self.local_config,
+                                                                code_handlers=code_handlers,)
         self.last_flow_run = {}
         # Fetch dynamic config info
         self.tokens = tokens or {}
@@ -287,8 +293,7 @@ class CfdeClient():
         BDBag API (see https://github.com/fair-research/bdbag for details).
         """
         self.check()
-        if verbose:
-            print("Startup: Validating input")
+        logger.debug("Startup: Validating input")
 
         catalogs = self.remote_config['CATALOGS']
         if catalog_id in catalogs.keys():
@@ -299,10 +304,12 @@ class CfdeClient():
             schema = catalogs[catalog_id]
 
         # Coerces the BDBag path to a .zip archive
-        data_path = validation.validate_user_submission(
-            data_path, schema, output_dir=output_dir, delete_dir=delete_dir,
+        data_path = bdbag_utils.get_bag(
+            data_path, output_dir=output_dir, delete_dir=delete_dir,
             handle_git_repos=handle_git_repos, bdbag_kwargs=kwargs
         )
+        # Raises exc.ValidationException if something doesn't match up with the schema
+        validation.validate_user_submission(data_path, schema)
 
         flow_info = self.remote_config["FLOWS"][self.service_instance]
         dest_path = "{}{}".format(flow_info["cfde_ep_path"], os.path.basename(data_path))
@@ -349,14 +356,12 @@ class CfdeClient():
                 "data_url": data_url,
             })
 
-        if verbose:
-            print("Flow input populated:\n{}".format(json.dumps(flow_input, indent=4,
-                                                                sort_keys=True)))
+        logger.debug("Flow input populated:\n{}".format(json.dumps(flow_input, indent=4,
+                                                                   sort_keys=True)))
         # Get Flow scope
         flow_id = flow_info["flow_id"]
         # Start Flow
-        if verbose:
-            print("Starting Flow - Submitting data")
+        logger.debug("Starting Flow - Submitting data")
         try:
             flow_res = self.flow_client.run_flow(flow_id, self.flow_scope, flow_input)
         except globus_sdk.GlobusAPIError as e:
@@ -374,8 +379,7 @@ class CfdeClient():
             "flow_id": flow_id,
             "flow_instance_id": flow_res["action_id"]
         }
-        if verbose:
-            print("Flow started successfully.")
+        logger.debug("Flow started successfully.")
 
         return {
             "success": True,
